@@ -28,7 +28,7 @@
 
 package Config::Model::Searcher;
 BEGIN {
-  $Config::Model::Searcher::VERSION = '1.230';
+  $Config::Model::Searcher::VERSION = '1.231';
 }
 use Log::Log4perl qw(get_logger :levels);
 use Carp;
@@ -46,7 +46,7 @@ Config::Model::Searcher - Search an element in a configuration model
 
 =head1 VERSION
 
-version 1.230
+version 1.231
 
 =head1 SYNOPSIS
 
@@ -89,7 +89,7 @@ remember where is this parameter in the configuration tree. This module
 will guide you through the tree to the(s) node(s) that contain this
 parameter.
 
-This class should be invaluable to construct interactive GUIs.
+This class should be invaluable to construct interactive user interfaces.
 
 This module provides 2 search modes:
 
@@ -243,7 +243,7 @@ sub prepare {
 	  croak "Searcher->prepare: Missing $p parameter" ;
     }
 
-    $self->reset ; # initialise the search engine
+    $self->reset ; # initialize the search engine
 
     unless (defined $self->{search_tree}) {
 	my $searched = $self->{element} ;
@@ -262,7 +262,7 @@ sub prepare {
 
 =head2 reset
 
-Re-initialise the search engine to redo the search from start
+Re-initialize the search engine to redo the search from start
 
 =cut
 
